/*
This file contains all the adjustable parameters for running the latticeeasy program. Once a particular model has been defined all runs can be done by changing the parameters in this file and recompiling. See the documentation for how to define new models.
*/

// Model specific adjustable parameters - This section should be replaced by the appropriate one for the model being used.
// (These definitions can be left in model.h but by putting them here you have all the adjustable parameters in one file.)
// ---Adjustable parameters for TWOFLDLAMBDA model--- //
const float lambda=9.e-14; // Self-coupling of inflaton
const float gl=200; // Resonance parameter g^2/lambda

// Adjustable run parameters
const int N = 64; // Number of points along each edge of the cubical lattice
const int nflds = 2;  //Number of fields
const float L = 8.4823; // Size of box (i.e. length of each edge) in rescaled distance units
const float dt = .006627; // Size of time step
const float tf=2400.; // Final time
const int seed=1; // Random number seed. Should be a positive integer
const float initfield[]={1.}; // Initial values of the fields in program units. All nonspecified values are taken to be zero.
const float initderivs[]={0.}; // Initial values of the field derivatives in program units. All nonspecified values are taken to be zero.
const int expansion=2; // Whether to use no expansion (0), power-law expansion (1), or self-consistent expansion (2)
const float expansion_power=.5; // Power of t in power law expansion. Only used when expansion=1.. Set to .5 for radiation or .67 for matter domination.

// Variables controlling output
const int noutput_flds=0; // Number of fields to output information about. All fields will be output nflds if noutput=0 or noutput>nflds
const char alt_extension[]=""; // Optional alternative extension for output files (default is the run number)
const int noutput_times=1000; // Number of times at which to calculate and save output variables
const int print_interval=1; // Interval in seconds between successive outputs of time
const int screen_updates=0; // Set to 1 for time to be periodically output to screen (0 otherwise)
const float checkpoint_interval=10.; // How often to output a grid image and perform infrequent calculations (see list below). Only done at end if checkpoint_interval=0.
const float store_lattice_times[]={1.}; // An optional list of times at which to close the grid image file and open a new one.
// The variables s<name> control what will be saved (1=save, 0=don't save)
const int smeansvars=1; // Output means and variances
const int sexpansion=1; // Output scale factor, Hubble constant, and a'' (This is ignored except in self-consistent expansion.)
const int smodel=0; // Call model-specific output functions  
// The following calculations are performed at intervals given by checkpoint_interval
const int sspectra=1; // Output power spectra
const int senergy=1; // Output components of energy density
const int shistograms=1; const int nbins=256; // Output histograms of fields using nbins as the number of bins
const int shistograms2d=1; const int nbins0=10; const int nbins1=10; const int hist2dflds[]={0,1}; // Output two dimensional histograms of fields. The number of bins in each field direction is given by nbin0 and nbin1. The array hist2dflds lists pairs of fields to be evaluated. This array should always contain an even number of integers







